diff -Naur debhelper-3.4.7.old/dh_installdocs debhelper-3.4.7/dh_installdocs
--- debhelper-3.4.7.old/dh_installdocs	Sun Nov 18 01:17:16 2001
+++ debhelper-3.4.7/dh_installdocs	Wed Feb 13 16:09:15 2002
@@ -11,7 +11,7 @@
 
 =head1 SYNOPSIS
 
-B<dh_installdocs> [S<I<debhelper options>>] [B<-A>] [B<-n>] [S<I<file ...>>]
+B<dh_installdocs> [S<I<debhelper options>>] [B<-A>] [B<-n>] [B<-X>I<item>] [S<I<file ...>>]
 
 =head1 DESCRIPTION
 
@@ -26,7 +26,7 @@
 
 Any filenames specified as parameters will be installed into the first
 package dh_installdocs is told to act on. By default, this is the first
-binary package in debian/control, but if you use -p, -i, or -a flags, it
+binary package in debian/control, but if you use B<-p>, B<-i>, or B<-a> flags, it
 will be the first package specified by those flags.
 
 Also, debian/README.Debian (or debian/README.debian) and debian/TODO, if
@@ -66,20 +66,25 @@
 
 Do not modify postinst/prerm scripts.
 
+=item B<-Xitem>, B<--exclude=item>
+
+Exclude files that contain "item" anywhere in their filename from
+being listed in the md5sums file.
+
 =item I<file ...>
 
 Install these files as documentation into the first package acted on. (Or
-in all packages if -A is specified).
+in all packages if B<-A> is specified).
 
 =back
 
 =head1 NOTES
 
 Note that dh_installdocs will happily copy entire directory hierarchies if
-you ask it to (it uses cp -a internally). If it is asked to install a
+you ask it to (it uses cp B<-a> internally). If it is asked to install a
 directory, it will install the complete contents of the directory.
 
-Note that this command is not idempotent. "dh_clean -k" should be called
+Note that this command is not idempotent. "dh_clean B<-k>" should be called
 between invocations of this command. Otherwise, it may cause multiple
 instances of the same text to be added to maintainer scripts.
 
@@ -87,6 +92,16 @@
 
 init();
 
+sub exclude_file
+{
+	my ($filename) = @_;
+	foreach my $f (@{$dh{EXCLUDE}}) {
+		return 1 if $filename =~ /$f/;
+	}
+	print "ok $filename\n";
+	return 0;
+}
+
 foreach my $package (@{$dh{DOPACKAGES}}) {
 	my $tmp=tmpdir($package);
 	my $file=pkgfile($package,"docs");
@@ -108,7 +123,23 @@
 	}
 
 	if (@docs) {
-		doit("cp", "-a",@docs,"$tmp/usr/share/doc/$package/");
+		my ($exclude) = '';
+		if ($dh{EXCLUDE_FIND})
+		{
+			$exclude = ' \( ! ' . $dh{EXCLUDE_FIND} . ' \)';
+		}
+		foreach my $doc (@docs)
+		{
+			if (-d $doc)
+			{
+			    my ($dir_basename) = basename($doc);
+			    complex_doit("cd $doc/.. && find $dir_basename -type f$exclude -exec cp -Pdp {} $ENV{PWD}/$tmp/usr/share/doc/$package \\;");
+			}
+			else
+			{
+				doit("cp","-dp",$doc,"$tmp/usr/share/doc/$package");
+			}
+		}
 		doit("chown","-R","0.0","$tmp/usr/share/doc");
 		doit("chmod","-R","go=rX","$tmp/usr/share/doc");
 		doit("chmod","-R","u+rw","$tmp/usr/share/doc");
@@ -119,13 +150,13 @@
 	if (! $readme_debian) {
 		$readme_debian=pkgfile($package,'README.debian');
 	}
-	if ($readme_debian) {
+	if ($readme_debian && ! exclude_file($readme_debian)) {
 		doit("install","-g",0,"-o",0,"-m","644","-p","$readme_debian",
 			"$tmp/usr/share/doc/$package/README.Debian");
 	}
 
 	my $todo=pkgfile($package,'TODO');
-	if ($todo) {
+	if ($todo && ! exclude_file($todo)) {
 		if (isnative($package)) {
 			doit("install","-g",0,"-o",0,"-m","644","-p",$todo,
 				"$tmp/usr/share/doc/$package/TODO");
@@ -147,7 +178,7 @@
 		if (! $copyright && -e "debian/copyright") {
 			$copyright="debian/copyright";
 		}
-		if ($copyright) {
+		if ($copyright && ! exclude_file($copyright)) {
 				doit("install","-g",0,"-o",0,"-m","644","-p",$copyright,
 					"$tmp/usr/share/doc/$package/copyright");
 		}
